@@ -3,11 +3,11 @@ package MojoX::Session;
 use strict;
 use warnings;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use base 'Mojo::Base';
 
-use Digest::SHA1 'sha1_hex';
+use Digest::SHA1;
 
 __PACKAGE__->attr('store', chained => 1);
 __PACKAGE__->attr('transport', chained => 1);
@@ -363,6 +363,7 @@ L<CGI::Session>, L<HTTP::Session>
 
 vti, C<vti@cpan.org>.
 
+
 =head1 COPYRIGHT
 
 Copyright (C) 2008, Viacheslav Tikhanovskii.
